@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.cpp,v 1.35 2006/09/13 19:01:22 chpe Exp $
+ *  $Id: mozilla-helpers.cpp 1439 2007-01-20 22:46:40Z jframeau $
  */
 
 #include "mozilla-config.h"
@@ -997,7 +997,7 @@ PageInfoHelper::WalkTree (nsIDOMDocument *aDocument)
 		      if (NS_SUCCEEDED (rv) && stringValue.Length())
 		      	{
                           EmbedPageMedium *medium = g_new0 (EmbedPageMedium, 1);
-                          medium->type = MEDIUM_IMAGE;
+                          medium->type = MEDIUM_BG_IMAGE;
                           medium->url = ToCString (stringValue);
                           g_hash_table_insert(mMediaHash, medium->url, medium);
 			}
