@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-sample.cpp,v 1.4 2006/09/13 19:01:32 chpe Exp $
+ *  $Id: mozilla-sample.cpp 1415 2006-12-23 21:22:06Z jframeau $
  */
 
 #include "mozilla-config.h"
@@ -33,12 +33,14 @@
 void
 mozilla_do_something (gpointer dom_event)
 {
-	nsCOMPtr<nsIDOMMouseEvent> ev = static_cast<nsIDOMMouseEvent*>(dom_event);
+	nsCOMPtr<nsIDOMEvent> ev = static_cast<nsIDOMEvent*>(dom_event);
 	NS_ENSURE_TRUE (ev,);
+	nsCOMPtr<nsIDOMMouseEvent> mev = do_QueryInterface (ev);
+	NS_ENSURE_TRUE (mev,);
 
 	nsresult rv;
 	PRUint16 button;
-	rv = ev->GetButton (&button);
+	rv = mev->GetButton (&button);
 	NS_ENSURE_SUCCESS (rv,);
 
 	g_print ("Button %u\n", button);
