@@ -1,8 +1,8 @@
 /*
- *  Copyright (C) 2002  Ricardo Fernández Pascual
- *  Copyright (C) 2004  Crispin Flowerday
- *  Copyright (C) 2004  Adam Hooper
- *  Copyright (C) 2004  Christian Persch
+ *  Copyright © 2002  Ricardo Fernández Pascual
+ *  Copyright © 2004  Crispin Flowerday
+ *  Copyright © 2004  Adam Hooper
+ *  Copyright © 2004  Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-css-menu.c,v 1.13 2005/11/01 11:28:22 chpe Exp $
+ *  $Id: ephy-css-menu.c 1376 2006-09-13 19:01:42Z chpe $
  */
 
 #include "config.h"
@@ -89,7 +89,7 @@ ephy_css_menu_get_type (void)
 GType
 ephy_css_menu_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyCSSMenuClass),
 		NULL, /* base_init */
